@@ -56,48 +56,41 @@ def _query_list(api_cls, parent, data):
         for obj in objs:
             yield api_cls(parent, obj)
 
-def list_fn(api, parent, url, limit=None, page=None,
-            per_page=None, addl_keys=[], **data):
-    print "list_fn:", url
-    print "list_fn:", addl_keys 
-    ret = []
-    if limit:  # Give limit precedence over other params if misused
-        page = None
-        per_page = None
-    if limit and limit <= _MAX_PER_PAGE:
-        per_page = limit
-        limit = None
-
-    if page or per_page:
-        if page:
-            data['page'] = page
-        if per_page:
-            data['per_page'] = per_page
-        objs = parent._get(url, data=data)
-        for obj in objs:
-            ret.append(api(parent, obj))
-    elif limit:
-        data['per_page'] = _MAX_PER_PAGE
-        num_pages = int(ceil(float(limit) / _MAX_PER_PAGE))
-        remainder = limit % _MAX_PER_PAGE
-        for i in xrange(1, num_pages+1):
-            data['page'] = i
-            objs = parent._get(url, data=data)
-            if remainder and i == num_pages:  # Final request
-                objs = objs[:remainder]
-            for obj in objs:
-                ret.append(api(parent, obj))
-    else:  # Obtain full list
-        for api_obj in _query_list(api, parent, data):
-            ret.append(api_obj)
-    return ret
-
 
 def _add_list_fn(api, api_definition, parent):
     """Create a <PARENT_API>.<name>s() function"""
     def fn(limit=None, page=None, per_page=None, **data):
-        return flexible_list_fn(api, parent, api._uq_url,
-                                limit, page, per_page, **data)
+        ret = []
+        if limit:  # Give limit precedence over other params if misused
+            page = None
+            per_page = None
+        if limit and limit <= _MAX_PER_PAGE:
+            per_page = limit
+            limit = None
+
+        if page or per_page:
+            if page:
+                data['page'] = page
+            if per_page:
+                data['per_page'] = per_page
+            objs = parent._get(api._uq_url, data=data)
+            for obj in objs:
+                ret.append(api(parent, obj))
+        elif limit:
+            data['per_page'] = _MAX_PER_PAGE
+            num_pages = int(ceil(float(limit) / _MAX_PER_PAGE))
+            remainder = limit % _MAX_PER_PAGE
+            for i in xrange(1, num_pages+1):
+                data['page'] = i
+                objs = parent._get(api._uq_url, data=data)
+                if remainder and i == num_pages:  # Final request
+                    objs = objs[:remainder]
+                for obj in objs:
+                    ret.append(api(parent, obj))
+        else:  # Obtain full list
+            for api_obj in _query_list(api, parent, data):
+                ret.append(api_obj)
+        return ret
     setattr(parent, api_definition.plural_name(), fn)
     return fn
 
@@ -230,7 +223,7 @@ def _get_http_request_fn(api, method):
         return api._delete
 
 
-def _add_extra_fn(api, action_def, parent):
+def _add_extra_fn(api, action_def, parent=None):
     required_params = action_def.required_params
     # url_params are required params, but get passed as part of url
     url_params = re.findall(':(\w+)', action_def.url)
@@ -432,7 +425,7 @@ class _GitLabAPI(object):
 
     def _request(self, request_fn, api_url, addl_keys, data):
         url = self._get_url(api_url, addl_keys)
-        print "%s %s, data=%s" % (request_fn.__name__.upper(), url, str(data))
+        #print "%s %s, data=%s" % (request_fn.__name__.upper(), url, str(data))
         try:
             r = request_fn(url, headers=self._headers, data=data,
                            **self._requests_kwargs)
@@ -469,7 +462,7 @@ class GitLab(_GitLabAPI):
             # Populate the module namespace with core classes
             globals()[cls_name] = cls
         for action_def in _GitLabAPIDefinition.extra_actions:
-            _add_extra_fn(GitLab, action_def, self)
+            _add_extra_fn(GitLab, action_def)
 
     def login(self, login_or_email, password):
         """Log in to GitLab. This is unnecessary if a token was given
